[−][src]Enum rusoto_lambda::CreateFunctionError
Errors returned by CreateFunction
Variants
CodeStorageExceeded(String)You have exceeded your maximum total code size per account. Limits
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
ResourceConflict(String)The resource already exists.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
ParseError(String)An error occurred parsing the response payload.
Unknown(BufferedHttpResponse)An unknown error occurred. The raw HTTP response is provided.
Methods
impl CreateFunctionError[src]
impl CreateFunctionErrorpub fn from_response(res: BufferedHttpResponse) -> CreateFunctionError[src]
pub fn from_response(res: BufferedHttpResponse) -> CreateFunctionErrorTrait Implementations
impl PartialEq<CreateFunctionError> for CreateFunctionError[src]
impl PartialEq<CreateFunctionError> for CreateFunctionErrorfn eq(&self, other: &CreateFunctionError) -> bool[src]
fn eq(&self, other: &CreateFunctionError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &CreateFunctionError) -> bool[src]
fn ne(&self, other: &CreateFunctionError) -> boolThis method tests for !=.
impl From<Error> for CreateFunctionError[src]
impl From<Error> for CreateFunctionErrorfn from(err: Error) -> CreateFunctionError[src]
fn from(err: Error) -> CreateFunctionErrorPerforms the conversion.
impl From<CredentialsError> for CreateFunctionError[src]
impl From<CredentialsError> for CreateFunctionErrorfn from(err: CredentialsError) -> CreateFunctionError[src]
fn from(err: CredentialsError) -> CreateFunctionErrorPerforms the conversion.
impl From<HttpDispatchError> for CreateFunctionError[src]
impl From<HttpDispatchError> for CreateFunctionErrorfn from(err: HttpDispatchError) -> CreateFunctionError[src]
fn from(err: HttpDispatchError) -> CreateFunctionErrorPerforms the conversion.
impl From<Error> for CreateFunctionError[src]
impl From<Error> for CreateFunctionErrorfn from(err: Error) -> CreateFunctionError[src]
fn from(err: Error) -> CreateFunctionErrorPerforms the conversion.
impl Debug for CreateFunctionError[src]
impl Debug for CreateFunctionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for CreateFunctionError[src]
impl Display for CreateFunctionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for CreateFunctionError[src]
impl Error for CreateFunctionErrorfn description(&self) -> &str[src]
fn description(&self) -> &strThis method is soft-deprecated. Read more
fn cause(&self) -> Option<&dyn Error>1.0.0[src]
fn cause(&self) -> Option<&dyn Error>: replaced by Error::source, which can support downcasting
The lower-level cause of this error, if any. Read more
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>The lower-level source of this error, if any. Read more