[−][src]Enum rusoto_lambda::DeleteEventSourceMappingError
Errors returned by DeleteEventSourceMapping
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
ResourceInUse(String)The operation conflicts with the resource's availability. For example, you attempted to update an EventSoure Mapping in CREATING, or tried to delete a EventSoure mapping currently in the UPDATING state.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
ParseError(String)An error occurred parsing the response payload.
Unknown(BufferedHttpResponse)An unknown error occurred. The raw HTTP response is provided.
Methods
impl DeleteEventSourceMappingError[src]
impl DeleteEventSourceMappingErrorpub fn from_response(res: BufferedHttpResponse) -> DeleteEventSourceMappingError[src]
pub fn from_response(res: BufferedHttpResponse) -> DeleteEventSourceMappingErrorTrait Implementations
impl PartialEq<DeleteEventSourceMappingError> for DeleteEventSourceMappingError[src]
impl PartialEq<DeleteEventSourceMappingError> for DeleteEventSourceMappingErrorfn eq(&self, other: &DeleteEventSourceMappingError) -> bool[src]
fn eq(&self, other: &DeleteEventSourceMappingError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &DeleteEventSourceMappingError) -> bool[src]
fn ne(&self, other: &DeleteEventSourceMappingError) -> boolThis method tests for !=.
impl From<Error> for DeleteEventSourceMappingError[src]
impl From<Error> for DeleteEventSourceMappingErrorfn from(err: Error) -> DeleteEventSourceMappingError[src]
fn from(err: Error) -> DeleteEventSourceMappingErrorPerforms the conversion.
impl From<CredentialsError> for DeleteEventSourceMappingError[src]
impl From<CredentialsError> for DeleteEventSourceMappingErrorfn from(err: CredentialsError) -> DeleteEventSourceMappingError[src]
fn from(err: CredentialsError) -> DeleteEventSourceMappingErrorPerforms the conversion.
impl From<HttpDispatchError> for DeleteEventSourceMappingError[src]
impl From<HttpDispatchError> for DeleteEventSourceMappingErrorfn from(err: HttpDispatchError) -> DeleteEventSourceMappingError[src]
fn from(err: HttpDispatchError) -> DeleteEventSourceMappingErrorPerforms the conversion.
impl From<Error> for DeleteEventSourceMappingError[src]
impl From<Error> for DeleteEventSourceMappingErrorfn from(err: Error) -> DeleteEventSourceMappingError[src]
fn from(err: Error) -> DeleteEventSourceMappingErrorPerforms the conversion.
impl Debug for DeleteEventSourceMappingError[src]
impl Debug for DeleteEventSourceMappingErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for DeleteEventSourceMappingError[src]
impl Display for DeleteEventSourceMappingErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for DeleteEventSourceMappingError[src]
impl Error for DeleteEventSourceMappingErrorfn description(&self) -> &str[src]
fn description(&self) -> &strThis method is soft-deprecated. Read more
fn cause(&self) -> Option<&dyn Error>1.0.0[src]
fn cause(&self) -> Option<&dyn Error>: replaced by Error::source, which can support downcasting
The lower-level cause of this error, if any. Read more
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>The lower-level source of this error, if any. Read more