Enum rusoto_lambda::GetFunctionError
[−]
[src]
pub enum GetFunctionError {
InvalidParameterValue(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by GetFunction
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception. You will also get this exception if you have selected a deprecated runtime, such as Node v0.10.42.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl GetFunctionError[src]
fn from_body(body: &str) -> GetFunctionError[src]