Enum rusoto_lambda::InvokeAsyncError
[−]
[src]
pub enum InvokeAsyncError {
InvalidRequestContent(String),
ResourceNotFound(String),
Service(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by InvokeAsync
Variants
InvalidRequestContent(String)The request body could not be parsed as JSON.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl InvokeAsyncError[src]
fn from_body(body: &str) -> InvokeAsyncError