[][src]Enum rusoto_lambda::ListLayersError

pub enum ListLayersError {
    InvalidParameterValue(String),
    Service(String),
    TooManyRequests(String),
}

Errors returned by ListLayers

Variants

InvalidParameterValue(String)

One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.

Service(String)

The AWS Lambda service encountered an internal error.

TooManyRequests(String)

Request throughput limit exceeded.

Methods

impl ListLayersError[src]