[−][src]Enum rusoto_lambda::ListProvisionedConcurrencyConfigsError
Errors returned by ListProvisionedConcurrencyConfigs
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid.
ResourceNotFound(String)The resource specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)The request throughput limit was exceeded.
Implementations
impl ListProvisionedConcurrencyConfigsError[src]
pub fn from_response(
res: BufferedHttpResponse
) -> RusotoError<ListProvisionedConcurrencyConfigsError>[src]
res: BufferedHttpResponse
) -> RusotoError<ListProvisionedConcurrencyConfigsError>