[−][src]Enum rusoto_lambda::ListVersionsByFunctionError
Errors returned by ListVersionsByFunction
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)Request throughput limit exceeded.
Methods
impl ListVersionsByFunctionError[src]
pub fn from_response(
res: BufferedHttpResponse
) -> RusotoError<ListVersionsByFunctionError>[src]
res: BufferedHttpResponse
) -> RusotoError<ListVersionsByFunctionError>