[][src]Enum rusoto_lambda::RemovePermissionError

pub enum RemovePermissionError {
    InvalidParameterValue(String),
    PreconditionFailed(String),
    ResourceNotFound(String),
    Service(String),
    TooManyRequests(String),
    HttpDispatch(HttpDispatchError),
    Credentials(CredentialsError),
    Validation(String),
    ParseError(String),
    Unknown(BufferedHttpResponse),
}

Errors returned by RemovePermission

Variants

One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.

The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.

The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.

The AWS Lambda service encountered an internal error.

An error occurred dispatching the HTTP request

An error was encountered with AWS credentials.

A validation error occurred. Details from AWS are provided.

An error occurred parsing the response payload.

An unknown error occurred. The raw HTTP response is provided.

Methods

impl RemovePermissionError
[src]