[−][src]Enum rusoto_lambda::UpdateAliasError
Errors returned by UpdateAlias
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid.
PreconditionFailed(String)The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceConflict(String)The resource already exists, or another operation is in progress.
ResourceNotFound(String)The resource specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)The request throughput limit was exceeded.
Methods
impl UpdateAliasError[src]
pub fn from_response(res: BufferedHttpResponse) -> RusotoError<UpdateAliasError>[src]