Enum rusoto_lambda::UpdateFunctionCodeError [−][src]
pub enum UpdateFunctionCodeError {
CodeStorageExceeded(String),
InvalidParameterValue(String),
PreconditionFailed(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by UpdateFunctionCode
Variants
CodeStorageExceeded(String)You have exceeded your maximum total code size per account. Limits
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
PreconditionFailed(String)The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl UpdateFunctionCodeError[src]
impl UpdateFunctionCodeErrorpub fn from_body(body: &str) -> UpdateFunctionCodeError[src]
pub fn from_body(body: &str) -> UpdateFunctionCodeErrorTrait Implementations
impl Debug for UpdateFunctionCodeError[src]
impl Debug for UpdateFunctionCodeErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for UpdateFunctionCodeError[src]
impl PartialEq for UpdateFunctionCodeErrorfn eq(&self, other: &UpdateFunctionCodeError) -> bool[src]
fn eq(&self, other: &UpdateFunctionCodeError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &UpdateFunctionCodeError) -> bool[src]
fn ne(&self, other: &UpdateFunctionCodeError) -> boolThis method tests for !=.
impl From<Error> for UpdateFunctionCodeError[src]
impl From<Error> for UpdateFunctionCodeErrorfn from(err: Error) -> UpdateFunctionCodeError[src]
fn from(err: Error) -> UpdateFunctionCodeErrorPerforms the conversion.
impl From<CredentialsError> for UpdateFunctionCodeError[src]
impl From<CredentialsError> for UpdateFunctionCodeErrorfn from(err: CredentialsError) -> UpdateFunctionCodeError[src]
fn from(err: CredentialsError) -> UpdateFunctionCodeErrorPerforms the conversion.
impl From<HttpDispatchError> for UpdateFunctionCodeError[src]
impl From<HttpDispatchError> for UpdateFunctionCodeErrorfn from(err: HttpDispatchError) -> UpdateFunctionCodeError[src]
fn from(err: HttpDispatchError) -> UpdateFunctionCodeErrorPerforms the conversion.
impl From<Error> for UpdateFunctionCodeError[src]
impl From<Error> for UpdateFunctionCodeErrorfn from(err: Error) -> UpdateFunctionCodeError[src]
fn from(err: Error) -> UpdateFunctionCodeErrorPerforms the conversion.
impl Display for UpdateFunctionCodeError[src]
impl Display for UpdateFunctionCodeErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for UpdateFunctionCodeError[src]
impl Error for UpdateFunctionCodeErrorAuto Trait Implementations
impl Send for UpdateFunctionCodeError
impl Send for UpdateFunctionCodeErrorimpl Sync for UpdateFunctionCodeError
impl Sync for UpdateFunctionCodeError