pub enum UpdateFunctionConfigurationError {
CodeSigningConfigNotFound(String),
CodeVerificationFailed(String),
InvalidCodeSignature(String),
InvalidParameterValue(String),
PreconditionFailed(String),
ResourceConflict(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
}Expand description
Errors returned by UpdateFunctionConfiguration
Variants
CodeSigningConfigNotFound(String)
The specified code signing configuration does not exist.
CodeVerificationFailed(String)
The code signature failed one or more of the validation checks for signature mismatch or expiry, and the code signing policy is set to ENFORCE. Lambda blocks the deployment.
InvalidCodeSignature(String)
The code signature failed the integrity check. Lambda always blocks deployment if the integrity check fails, even if code signing policy is set to WARN.
InvalidParameterValue(String)
One of the parameters in the request is invalid.
PreconditionFailed(String)
The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceConflict(String)
The resource already exists, or another operation is in progress.
ResourceNotFound(String)
The resource specified in the request does not exist.
Service(String)
The AWS Lambda service encountered an internal error.
TooManyRequests(String)
The request throughput limit was exceeded.
Implementations