[−][src]Struct rusoto_lambda::AccountLimit
Limits that are related to concurrency and storage. All file and storage sizes are in bytes.
Fields
code_size_unzipped: Option<i64>The maximum size of a function's deployment package and layers when they're extracted.
code_size_zipped: Option<i64>The maximum size of a deployment package when it's uploaded directly to AWS Lambda. Use Amazon S3 for larger files.
concurrent_executions: Option<i64>The maximum number of simultaneous function executions.
total_code_size: Option<i64>The amount of storage space that you can use for all deployment packages and layer archives.
unreserved_concurrent_executions: Option<i64>The maximum number of simultaneous function executions, minus the capacity that's reserved for individual functions with PutFunctionConcurrency.