Struct rusoto_lambda::AliasConfiguration [−][src]
pub struct AliasConfiguration {
pub alias_arn: Option<String>,
pub description: Option<String>,
pub function_version: Option<String>,
pub name: Option<String>,
pub revision_id: Option<String>,
pub routing_config: Option<AliasRoutingConfiguration>,
}Provides configuration information about a Lambda function version alias.
Fields
alias_arn: Option<String>
Lambda function ARN that is qualified using the alias name as the suffix. For example, if you create an alias called BETA that points to a helloworld function version, the ARN is arn:aws:lambda:aws-regions:acct-id:function:helloworld:BETA.
description: Option<String>
Alias description.
function_version: Option<String>
Function version to which the alias points.
name: Option<String>
Alias name.
revision_id: Option<String>
Represents the latest updated revision of the function or alias.
routing_config: Option<AliasRoutingConfiguration>
Specifies an additional function versions the alias points to, allowing you to dictate what percentage of traffic will invoke each version. For more information, see lambda-traffic-shifting-using-aliases.