[][src]Struct rusoto_lambda::DeadLetterConfig

pub struct DeadLetterConfig {
    pub target_arn: Option<String>,
}

The Amazon Resource Name (ARN) of an Amazon SQS queue or Amazon SNS topic you specify as your Dead Letter Queue (DLQ). For more information, see dlq.

Fields

The Amazon Resource Name (ARN) of an Amazon SQS queue or Amazon SNS topic you specify as your Dead Letter Queue (DLQ). dlq. For more information, see dlq.