Struct rusoto_lambda::EnvironmentError [−][src]
The parent object that contains error information associated with your configuration settings.
Fields
error_code: Option<String>
The error code returned by the environment error object.
message: Option<String>
The message returned by the environment error object.