[][src]Struct rusoto_lambda::EventSourceMappingConfiguration

pub struct EventSourceMappingConfiguration {
    pub batch_size: Option<i64>,
    pub event_source_arn: Option<String>,
    pub function_arn: Option<String>,
    pub last_modified: Option<f64>,
    pub last_processing_result: Option<String>,
    pub state: Option<String>,
    pub state_transition_reason: Option<String>,
    pub uuid: Option<String>,
}

Describes mapping between an Amazon Kinesis or DynamoDB stream or an Amazon SQS queue and a Lambda function.

Fields

The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records.

The Amazon Resource Name (ARN) of the Amazon Kinesis or DynamoDB stream or the SQS queue that is the source of events.

The Lambda function to invoke when AWS Lambda detects an event on the poll-based source.

The UTC time string indicating the last time the event mapping was updated.

The result of the last AWS Lambda invocation of your Lambda function.

The state of the event source mapping. It can be Creating, Enabled, Disabled, Enabling, Disabling, Updating, or Deleting.

The reason the event source mapping is in its current state. It is either user-requested or an AWS Lambda-initiated state transition.

The AWS Lambda assigned opaque identifier for the mapping.