Struct rusoto_lambda::GetFunctionResponse [] [src]

pub struct GetFunctionResponse {
    pub code: Option<FunctionCodeLocation>,
    pub configuration: Option<FunctionConfiguration>,
    pub tags: Option<HashMap<String, String>>,
}

This response contains the object for the Lambda function location (see FunctionCodeLocation.

Fields

Returns the list of tags associated with the function.