Struct rusoto_lambda::ListVersionsByFunctionRequest
[−]
[src]
pub struct ListVersionsByFunctionRequest {
pub function_name: FunctionName,
pub marker: Option<String>,
pub max_items: Option<MaxListItems>,
}Fields
function_name: FunctionName
Function name whose versions to list. You can specify a function name (for example, Thumbnail) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 characters in length.
marker: Option<String>
Optional string. An opaque pagination token returned from a previous ListVersionsByFunction operation. If present, indicates where to continue the listing.
max_items: Option<MaxListItems>
Optional integer. Specifies the maximum number of AWS Lambda function versions to return in response. This parameter value must be greater than 0.