[−][src]Struct rusoto_lambda::ProvisionedConcurrencyConfigListItem
Details about the provisioned concurrency configuration for a function alias or version.
Fields
allocated_provisioned_concurrent_executions: Option<i64>The amount of provisioned concurrency allocated.
available_provisioned_concurrent_executions: Option<i64>The amount of provisioned concurrency available.
function_arn: Option<String>The Amazon Resource Name (ARN) of the alias or version.
last_modified: Option<String>The date and time that a user last updated the configuration, in ISO 8601 format.
requested_provisioned_concurrent_executions: Option<i64>The amount of provisioned concurrency requested.
status: Option<String>The status of the allocation process.
status_reason: Option<String>For failed allocations, the reason that provisioned concurrency could not be allocated.