Struct rusoto_lambda::UntagResourceRequest [−][src]
Fields
resource: String
The ARN (Amazon Resource Name) of the function. For more information, see Tagging Lambda Functions in the AWS Lambda Developer Guide.
tag_keys: Vec<String>
The list of tag keys to be deleted from the function. For more information, see Tagging Lambda Functions in the AWS Lambda Developer Guide.