[−][src]Struct rusoto_lambda::UpdateAliasRequest
Fields
description: Option<String>A description of the alias.
function_name: StringThe name of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
function_version: Option<String>The function version that the alias invokes.
name: StringThe name of the alias.
revision_id: Option<String>Only update the alias if the revision ID matches the ID that's specified. Use this option to avoid modifying an alias that has changed since you last read it.
routing_config: Option<AliasRoutingConfiguration>The routing configuration of the alias.