[][src]Struct rusoto_lambda::VpcConfig

pub struct VpcConfig {
    pub security_group_ids: Option<Vec<String>>,
    pub subnet_ids: Option<Vec<String>>,
}

If your Lambda function accesses resources in a VPC, you provide this parameter identifying the list of security group IDs and subnet IDs. These must belong to the same VPC. You must provide at least one security group and one subnet ID.

Fields

A list of one or more security groups IDs in your VPC.

A list of one or more subnet IDs in your VPC.