[−][src]Enum rusoto_lambda::AddPermissionError
Errors returned by AddPermission
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
PolicyLengthExceeded(String)Lambda function access policy is limited to 20 KB.
PreconditionFailed(String)The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceConflict(String)The resource already exists.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
ParseError(String)An error occurred parsing the response payload.
Unknown(BufferedHttpResponse)An unknown error occurred. The raw HTTP response is provided.
Methods
impl AddPermissionError[src]
impl AddPermissionErrorpub fn from_response(res: BufferedHttpResponse) -> AddPermissionError[src]
pub fn from_response(res: BufferedHttpResponse) -> AddPermissionErrorTrait Implementations
impl PartialEq<AddPermissionError> for AddPermissionError[src]
impl PartialEq<AddPermissionError> for AddPermissionErrorfn eq(&self, other: &AddPermissionError) -> bool[src]
fn eq(&self, other: &AddPermissionError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &AddPermissionError) -> bool[src]
fn ne(&self, other: &AddPermissionError) -> boolThis method tests for !=.
impl From<Error> for AddPermissionError[src]
impl From<Error> for AddPermissionErrorfn from(err: Error) -> AddPermissionError[src]
fn from(err: Error) -> AddPermissionErrorPerforms the conversion.
impl From<CredentialsError> for AddPermissionError[src]
impl From<CredentialsError> for AddPermissionErrorfn from(err: CredentialsError) -> AddPermissionError[src]
fn from(err: CredentialsError) -> AddPermissionErrorPerforms the conversion.
impl From<HttpDispatchError> for AddPermissionError[src]
impl From<HttpDispatchError> for AddPermissionErrorfn from(err: HttpDispatchError) -> AddPermissionError[src]
fn from(err: HttpDispatchError) -> AddPermissionErrorPerforms the conversion.
impl From<Error> for AddPermissionError[src]
impl From<Error> for AddPermissionErrorfn from(err: Error) -> AddPermissionError[src]
fn from(err: Error) -> AddPermissionErrorPerforms the conversion.
impl Debug for AddPermissionError[src]
impl Debug for AddPermissionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for AddPermissionError[src]
impl Display for AddPermissionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for AddPermissionError[src]
impl Error for AddPermissionErrorfn description(&self) -> &str[src]
fn description(&self) -> &strThis method is soft-deprecated. Read more
fn cause(&self) -> Option<&dyn Error>1.0.0[src]
fn cause(&self) -> Option<&dyn Error>: replaced by Error::source, which can support downcasting
The lower-level cause of this error, if any. Read more
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>The lower-level source of this error, if any. Read more