Enum rusoto_lambda::AddPermissionError [−][src]
pub enum AddPermissionError {
InvalidParameterValue(String),
PolicyLengthExceeded(String),
PreconditionFailed(String),
ResourceConflict(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by AddPermission
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
PolicyLengthExceeded(String)Lambda function access policy is limited to 20 KB.
PreconditionFailed(String)The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceConflict(String)The resource already exists.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl AddPermissionError[src]
impl AddPermissionErrorpub fn from_body(body: &str) -> AddPermissionError[src]
pub fn from_body(body: &str) -> AddPermissionErrorTrait Implementations
impl Debug for AddPermissionError[src]
impl Debug for AddPermissionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for AddPermissionError[src]
impl PartialEq for AddPermissionErrorfn eq(&self, other: &AddPermissionError) -> bool[src]
fn eq(&self, other: &AddPermissionError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &AddPermissionError) -> bool[src]
fn ne(&self, other: &AddPermissionError) -> boolThis method tests for !=.
impl From<Error> for AddPermissionError[src]
impl From<Error> for AddPermissionErrorfn from(err: Error) -> AddPermissionError[src]
fn from(err: Error) -> AddPermissionErrorPerforms the conversion.
impl From<CredentialsError> for AddPermissionError[src]
impl From<CredentialsError> for AddPermissionErrorfn from(err: CredentialsError) -> AddPermissionError[src]
fn from(err: CredentialsError) -> AddPermissionErrorPerforms the conversion.
impl From<HttpDispatchError> for AddPermissionError[src]
impl From<HttpDispatchError> for AddPermissionErrorfn from(err: HttpDispatchError) -> AddPermissionError[src]
fn from(err: HttpDispatchError) -> AddPermissionErrorPerforms the conversion.
impl From<Error> for AddPermissionError[src]
impl From<Error> for AddPermissionErrorfn from(err: Error) -> AddPermissionError[src]
fn from(err: Error) -> AddPermissionErrorPerforms the conversion.
impl Display for AddPermissionError[src]
impl Display for AddPermissionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for AddPermissionError[src]
impl Error for AddPermissionErrorAuto Trait Implementations
impl Send for AddPermissionError
impl Send for AddPermissionErrorimpl Sync for AddPermissionError
impl Sync for AddPermissionError