Enum rusoto_lambda::CreateEventSourceMappingError [−][src]
pub enum CreateEventSourceMappingError {
InvalidParameterValue(String),
ResourceConflict(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by CreateEventSourceMapping
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
ResourceConflict(String)The resource already exists.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl CreateEventSourceMappingError[src]
impl CreateEventSourceMappingErrorpub fn from_body(body: &str) -> CreateEventSourceMappingError[src]
pub fn from_body(body: &str) -> CreateEventSourceMappingErrorTrait Implementations
impl Debug for CreateEventSourceMappingError[src]
impl Debug for CreateEventSourceMappingErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for CreateEventSourceMappingError[src]
impl PartialEq for CreateEventSourceMappingErrorfn eq(&self, other: &CreateEventSourceMappingError) -> bool[src]
fn eq(&self, other: &CreateEventSourceMappingError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &CreateEventSourceMappingError) -> bool[src]
fn ne(&self, other: &CreateEventSourceMappingError) -> boolThis method tests for !=.
impl From<Error> for CreateEventSourceMappingError[src]
impl From<Error> for CreateEventSourceMappingErrorfn from(err: Error) -> CreateEventSourceMappingError[src]
fn from(err: Error) -> CreateEventSourceMappingErrorPerforms the conversion.
impl From<CredentialsError> for CreateEventSourceMappingError[src]
impl From<CredentialsError> for CreateEventSourceMappingErrorfn from(err: CredentialsError) -> CreateEventSourceMappingError[src]
fn from(err: CredentialsError) -> CreateEventSourceMappingErrorPerforms the conversion.
impl From<HttpDispatchError> for CreateEventSourceMappingError[src]
impl From<HttpDispatchError> for CreateEventSourceMappingErrorfn from(err: HttpDispatchError) -> CreateEventSourceMappingError[src]
fn from(err: HttpDispatchError) -> CreateEventSourceMappingErrorPerforms the conversion.
impl From<Error> for CreateEventSourceMappingError[src]
impl From<Error> for CreateEventSourceMappingErrorfn from(err: Error) -> CreateEventSourceMappingError[src]
fn from(err: Error) -> CreateEventSourceMappingErrorPerforms the conversion.
impl Display for CreateEventSourceMappingError[src]
impl Display for CreateEventSourceMappingErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for CreateEventSourceMappingError[src]
impl Error for CreateEventSourceMappingErrorAuto Trait Implementations
impl Send for CreateEventSourceMappingError
impl Send for CreateEventSourceMappingErrorimpl Sync for CreateEventSourceMappingError
impl Sync for CreateEventSourceMappingError