[][src]Enum rusoto_lambda::InvokeError

pub enum InvokeError {
    EC2AccessDenied(String),
    EC2Throttled(String),
    EC2Unexpected(String),
    ENILimitReached(String),
    InvalidParameterValue(String),
    InvalidRequestContent(String),
    InvalidRuntime(String),
    InvalidSecurityGroupID(String),
    InvalidSubnetID(String),
    InvalidZipFile(String),
    KMSAccessDenied(String),
    KMSDisabled(String),
    KMSInvalidState(String),
    KMSNotFound(String),
    RequestTooLarge(String),
    ResourceNotFound(String),
    Service(String),
    SubnetIPAddressLimitReached(String),
    TooManyRequests(String),
    UnsupportedMediaType(String),
    HttpDispatch(HttpDispatchError),
    Credentials(CredentialsError),
    Validation(String),
    ParseError(String),
    Unknown(BufferedHttpResponse),
}

Errors returned by Invoke

Variants

AWS Lambda was throttled by Amazon EC2 during Lambda function initialization using the execution role provided for the Lambda function.

AWS Lambda received an unexpected EC2 client exception while setting up for the Lambda function.

AWS Lambda was not able to create an Elastic Network Interface (ENI) in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached.

One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.

The request body could not be parsed as JSON.

The runtime or runtime version specified is not supported.

The Security Group ID provided in the Lambda function VPC configuration is invalid.

The Subnet ID provided in the Lambda function VPC configuration is invalid.

AWS Lambda could not unzip the function zip file.

Lambda was unable to decrypt the environment variables because KMS access was denied. Check the Lambda function's KMS permissions.

Lambda was unable to decrypt the environment variables because the KMS key used is disabled. Check the Lambda function's KMS key settings.

Lambda was unable to decrypt the environment variables because the KMS key used is in an invalid state for Decrypt. Check the function's KMS key settings.

Lambda was unable to decrypt the environment variables because the KMS key was not found. Check the function's KMS key settings.

The request payload exceeded the Invoke request body JSON input limit. For more information, see Limits.

The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.

The AWS Lambda service encountered an internal error.

AWS Lambda was not able to set up VPC access for the Lambda function because one or more configured subnets has no available IP addresses.

The content type of the Invoke request body is not JSON.

An error occurred dispatching the HTTP request

An error was encountered with AWS credentials.

A validation error occurred. Details from AWS are provided.

An error occurred parsing the response payload.

An unknown error occurred. The raw HTTP response is provided.

Methods

impl InvokeError
[src]