[−][src]Enum rusoto_lambda::InvokeError
Errors returned by Invoke
Variants
EC2AccessDenied(String)EC2Throttled(String)AWS Lambda was throttled by Amazon EC2 during Lambda function initialization using the execution role provided for the Lambda function.
EC2Unexpected(String)AWS Lambda received an unexpected EC2 client exception while setting up for the Lambda function.
ENILimitReached(String)AWS Lambda was not able to create an Elastic Network Interface (ENI) in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached.
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
InvalidRequestContent(String)The request body could not be parsed as JSON.
InvalidRuntime(String)The runtime or runtime version specified is not supported.
InvalidSecurityGroupID(String)The Security Group ID provided in the Lambda function VPC configuration is invalid.
InvalidSubnetID(String)The Subnet ID provided in the Lambda function VPC configuration is invalid.
InvalidZipFile(String)AWS Lambda could not unzip the function zip file.
KMSAccessDenied(String)Lambda was unable to decrypt the environment variables because KMS access was denied. Check the Lambda function's KMS permissions.
KMSDisabled(String)Lambda was unable to decrypt the environment variables because the KMS key used is disabled. Check the Lambda function's KMS key settings.
KMSInvalidState(String)Lambda was unable to decrypt the environment variables because the KMS key used is in an invalid state for Decrypt. Check the function's KMS key settings.
KMSNotFound(String)Lambda was unable to decrypt the environment variables because the KMS key was not found. Check the function's KMS key settings.
RequestTooLarge(String)The request payload exceeded the Invoke request body JSON input limit. For more information, see Limits.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
SubnetIPAddressLimitReached(String)AWS Lambda was not able to set up VPC access for the Lambda function because one or more configured subnets has no available IP addresses.
TooManyRequests(String)
UnsupportedMediaType(String)The content type of the Invoke request body is not JSON.
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
ParseError(String)An error occurred parsing the response payload.
Unknown(BufferedHttpResponse)An unknown error occurred. The raw HTTP response is provided.
Methods
impl InvokeError[src]
impl InvokeErrorpub fn from_response(res: BufferedHttpResponse) -> InvokeError[src]
pub fn from_response(res: BufferedHttpResponse) -> InvokeErrorTrait Implementations
impl PartialEq<InvokeError> for InvokeError[src]
impl PartialEq<InvokeError> for InvokeErrorfn eq(&self, other: &InvokeError) -> bool[src]
fn eq(&self, other: &InvokeError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &InvokeError) -> bool[src]
fn ne(&self, other: &InvokeError) -> boolThis method tests for !=.
impl From<Error> for InvokeError[src]
impl From<Error> for InvokeErrorfn from(err: Error) -> InvokeError[src]
fn from(err: Error) -> InvokeErrorPerforms the conversion.
impl From<CredentialsError> for InvokeError[src]
impl From<CredentialsError> for InvokeErrorfn from(err: CredentialsError) -> InvokeError[src]
fn from(err: CredentialsError) -> InvokeErrorPerforms the conversion.
impl From<HttpDispatchError> for InvokeError[src]
impl From<HttpDispatchError> for InvokeErrorfn from(err: HttpDispatchError) -> InvokeError[src]
fn from(err: HttpDispatchError) -> InvokeErrorPerforms the conversion.
impl From<Error> for InvokeError[src]
impl From<Error> for InvokeErrorfn from(err: Error) -> InvokeError[src]
fn from(err: Error) -> InvokeErrorPerforms the conversion.
impl Debug for InvokeError[src]
impl Debug for InvokeErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for InvokeError[src]
impl Display for InvokeErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for InvokeError[src]
impl Error for InvokeErrorfn description(&self) -> &str[src]
fn description(&self) -> &strThis method is soft-deprecated. Read more
fn cause(&self) -> Option<&dyn Error>1.0.0[src]
fn cause(&self) -> Option<&dyn Error>: replaced by Error::source, which can support downcasting
The lower-level cause of this error, if any. Read more
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>The lower-level source of this error, if any. Read more