Enum rusoto_lambda::ListVersionsByFunctionError [−][src]
pub enum ListVersionsByFunctionError {
InvalidParameterValue(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by ListVersionsByFunction
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl ListVersionsByFunctionError[src]
impl ListVersionsByFunctionErrorpub fn from_body(body: &str) -> ListVersionsByFunctionError[src]
pub fn from_body(body: &str) -> ListVersionsByFunctionErrorTrait Implementations
impl Debug for ListVersionsByFunctionError[src]
impl Debug for ListVersionsByFunctionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for ListVersionsByFunctionError[src]
impl PartialEq for ListVersionsByFunctionErrorfn eq(&self, other: &ListVersionsByFunctionError) -> bool[src]
fn eq(&self, other: &ListVersionsByFunctionError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &ListVersionsByFunctionError) -> bool[src]
fn ne(&self, other: &ListVersionsByFunctionError) -> boolThis method tests for !=.
impl From<Error> for ListVersionsByFunctionError[src]
impl From<Error> for ListVersionsByFunctionErrorfn from(err: Error) -> ListVersionsByFunctionError[src]
fn from(err: Error) -> ListVersionsByFunctionErrorPerforms the conversion.
impl From<CredentialsError> for ListVersionsByFunctionError[src]
impl From<CredentialsError> for ListVersionsByFunctionErrorfn from(err: CredentialsError) -> ListVersionsByFunctionError[src]
fn from(err: CredentialsError) -> ListVersionsByFunctionErrorPerforms the conversion.
impl From<HttpDispatchError> for ListVersionsByFunctionError[src]
impl From<HttpDispatchError> for ListVersionsByFunctionErrorfn from(err: HttpDispatchError) -> ListVersionsByFunctionError[src]
fn from(err: HttpDispatchError) -> ListVersionsByFunctionErrorPerforms the conversion.
impl From<Error> for ListVersionsByFunctionError[src]
impl From<Error> for ListVersionsByFunctionErrorfn from(err: Error) -> ListVersionsByFunctionError[src]
fn from(err: Error) -> ListVersionsByFunctionErrorPerforms the conversion.
impl Display for ListVersionsByFunctionError[src]
impl Display for ListVersionsByFunctionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for ListVersionsByFunctionError[src]
impl Error for ListVersionsByFunctionErrorAuto Trait Implementations
impl Send for ListVersionsByFunctionError
impl Send for ListVersionsByFunctionErrorimpl Sync for ListVersionsByFunctionError
impl Sync for ListVersionsByFunctionError