[−][src]Enum rusoto_lambda::RemovePermissionError
Errors returned by RemovePermission
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
PreconditionFailed(String)The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
ParseError(String)An error occurred parsing the response payload.
Unknown(BufferedHttpResponse)An unknown error occurred. The raw HTTP response is provided.
Methods
impl RemovePermissionError[src]
impl RemovePermissionErrorpub fn from_response(res: BufferedHttpResponse) -> RemovePermissionError[src]
pub fn from_response(res: BufferedHttpResponse) -> RemovePermissionErrorTrait Implementations
impl From<Error> for RemovePermissionError[src]
impl From<Error> for RemovePermissionErrorfn from(err: Error) -> RemovePermissionError[src]
fn from(err: Error) -> RemovePermissionErrorimpl From<CredentialsError> for RemovePermissionError[src]
impl From<CredentialsError> for RemovePermissionErrorfn from(err: CredentialsError) -> RemovePermissionError[src]
fn from(err: CredentialsError) -> RemovePermissionErrorimpl From<HttpDispatchError> for RemovePermissionError[src]
impl From<HttpDispatchError> for RemovePermissionErrorfn from(err: HttpDispatchError) -> RemovePermissionError[src]
fn from(err: HttpDispatchError) -> RemovePermissionErrorimpl From<Error> for RemovePermissionError[src]
impl From<Error> for RemovePermissionErrorfn from(err: Error) -> RemovePermissionError[src]
fn from(err: Error) -> RemovePermissionErrorimpl PartialEq<RemovePermissionError> for RemovePermissionError[src]
impl PartialEq<RemovePermissionError> for RemovePermissionErrorfn eq(&self, other: &RemovePermissionError) -> bool[src]
fn eq(&self, other: &RemovePermissionError) -> boolfn ne(&self, other: &RemovePermissionError) -> bool[src]
fn ne(&self, other: &RemovePermissionError) -> boolimpl Debug for RemovePermissionError[src]
impl Debug for RemovePermissionErrorimpl Display for RemovePermissionError[src]
impl Display for RemovePermissionErrorimpl Error for RemovePermissionError[src]
impl Error for RemovePermissionErrorfn description(&self) -> &str[src]
fn description(&self) -> &strfn cause(&self) -> Option<&dyn Error>1.0.0[src]
fn cause(&self) -> Option<&dyn Error>: replaced by Error::source, which can support downcasting
The lower-level cause of this error, if any. Read more
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>The lower-level source of this error, if any. Read more