Enum rusoto_lambda::RemovePermissionError [−][src]
pub enum RemovePermissionError {
InvalidParameterValue(String),
PreconditionFailed(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by RemovePermission
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
PreconditionFailed(String)The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl RemovePermissionError[src]
impl RemovePermissionErrorpub fn from_body(body: &str) -> RemovePermissionError[src]
pub fn from_body(body: &str) -> RemovePermissionErrorTrait Implementations
impl Debug for RemovePermissionError[src]
impl Debug for RemovePermissionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for RemovePermissionError[src]
impl PartialEq for RemovePermissionErrorfn eq(&self, other: &RemovePermissionError) -> bool[src]
fn eq(&self, other: &RemovePermissionError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &RemovePermissionError) -> bool[src]
fn ne(&self, other: &RemovePermissionError) -> boolThis method tests for !=.
impl From<Error> for RemovePermissionError[src]
impl From<Error> for RemovePermissionErrorfn from(err: Error) -> RemovePermissionError[src]
fn from(err: Error) -> RemovePermissionErrorPerforms the conversion.
impl From<CredentialsError> for RemovePermissionError[src]
impl From<CredentialsError> for RemovePermissionErrorfn from(err: CredentialsError) -> RemovePermissionError[src]
fn from(err: CredentialsError) -> RemovePermissionErrorPerforms the conversion.
impl From<HttpDispatchError> for RemovePermissionError[src]
impl From<HttpDispatchError> for RemovePermissionErrorfn from(err: HttpDispatchError) -> RemovePermissionError[src]
fn from(err: HttpDispatchError) -> RemovePermissionErrorPerforms the conversion.
impl From<Error> for RemovePermissionError[src]
impl From<Error> for RemovePermissionErrorfn from(err: Error) -> RemovePermissionError[src]
fn from(err: Error) -> RemovePermissionErrorPerforms the conversion.
impl Display for RemovePermissionError[src]
impl Display for RemovePermissionErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for RemovePermissionError[src]
impl Error for RemovePermissionErrorAuto Trait Implementations
impl Send for RemovePermissionError
impl Send for RemovePermissionErrorimpl Sync for RemovePermissionError
impl Sync for RemovePermissionError