[−][src]Enum rusoto_lambda::UntagResourceError
Errors returned by UntagResource
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
ParseError(String)An error occurred parsing the response payload.
Unknown(BufferedHttpResponse)An unknown error occurred. The raw HTTP response is provided.
Methods
impl UntagResourceError[src]
impl UntagResourceErrorpub fn from_response(res: BufferedHttpResponse) -> UntagResourceError[src]
pub fn from_response(res: BufferedHttpResponse) -> UntagResourceErrorTrait Implementations
impl From<Error> for UntagResourceError[src]
impl From<Error> for UntagResourceErrorfn from(err: Error) -> UntagResourceError[src]
fn from(err: Error) -> UntagResourceErrorimpl From<CredentialsError> for UntagResourceError[src]
impl From<CredentialsError> for UntagResourceErrorfn from(err: CredentialsError) -> UntagResourceError[src]
fn from(err: CredentialsError) -> UntagResourceErrorimpl From<HttpDispatchError> for UntagResourceError[src]
impl From<HttpDispatchError> for UntagResourceErrorfn from(err: HttpDispatchError) -> UntagResourceError[src]
fn from(err: HttpDispatchError) -> UntagResourceErrorimpl From<Error> for UntagResourceError[src]
impl From<Error> for UntagResourceErrorfn from(err: Error) -> UntagResourceError[src]
fn from(err: Error) -> UntagResourceErrorimpl PartialEq<UntagResourceError> for UntagResourceError[src]
impl PartialEq<UntagResourceError> for UntagResourceErrorfn eq(&self, other: &UntagResourceError) -> bool[src]
fn eq(&self, other: &UntagResourceError) -> boolfn ne(&self, other: &UntagResourceError) -> bool[src]
fn ne(&self, other: &UntagResourceError) -> boolimpl Debug for UntagResourceError[src]
impl Debug for UntagResourceErrorimpl Display for UntagResourceError[src]
impl Display for UntagResourceErrorimpl Error for UntagResourceError[src]
impl Error for UntagResourceErrorfn description(&self) -> &str[src]
fn description(&self) -> &strfn cause(&self) -> Option<&dyn Error>1.0.0[src]
fn cause(&self) -> Option<&dyn Error>: replaced by Error::source, which can support downcasting
The lower-level cause of this error, if any. Read more
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>The lower-level source of this error, if any. Read more