Enum rusoto_lambda::UpdateAliasError [−][src]
pub enum UpdateAliasError {
InvalidParameterValue(String),
PreconditionFailed(String),
ResourceNotFound(String),
Service(String),
TooManyRequests(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by UpdateAlias
Variants
InvalidParameterValue(String)One of the parameters in the request is invalid. For example, if you provided an IAM role for AWS Lambda to assume in the CreateFunction or the UpdateFunctionConfiguration API, that AWS Lambda is unable to assume you will get this exception.
PreconditionFailed(String)The RevisionId provided does not match the latest RevisionId for the Lambda function or alias. Call the GetFunction or the GetAlias API to retrieve the latest RevisionId for your resource.
ResourceNotFound(String)The resource (for example, a Lambda function or access policy statement) specified in the request does not exist.
Service(String)The AWS Lambda service encountered an internal error.
TooManyRequests(String)
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl UpdateAliasError[src]
impl UpdateAliasErrorpub fn from_body(body: &str) -> UpdateAliasError[src]
pub fn from_body(body: &str) -> UpdateAliasErrorTrait Implementations
impl Debug for UpdateAliasError[src]
impl Debug for UpdateAliasErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for UpdateAliasError[src]
impl PartialEq for UpdateAliasErrorfn eq(&self, other: &UpdateAliasError) -> bool[src]
fn eq(&self, other: &UpdateAliasError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &UpdateAliasError) -> bool[src]
fn ne(&self, other: &UpdateAliasError) -> boolThis method tests for !=.
impl From<Error> for UpdateAliasError[src]
impl From<Error> for UpdateAliasErrorfn from(err: Error) -> UpdateAliasError[src]
fn from(err: Error) -> UpdateAliasErrorPerforms the conversion.
impl From<CredentialsError> for UpdateAliasError[src]
impl From<CredentialsError> for UpdateAliasErrorfn from(err: CredentialsError) -> UpdateAliasError[src]
fn from(err: CredentialsError) -> UpdateAliasErrorPerforms the conversion.
impl From<HttpDispatchError> for UpdateAliasError[src]
impl From<HttpDispatchError> for UpdateAliasErrorfn from(err: HttpDispatchError) -> UpdateAliasError[src]
fn from(err: HttpDispatchError) -> UpdateAliasErrorPerforms the conversion.
impl From<Error> for UpdateAliasError[src]
impl From<Error> for UpdateAliasErrorfn from(err: Error) -> UpdateAliasError[src]
fn from(err: Error) -> UpdateAliasErrorPerforms the conversion.
impl Display for UpdateAliasError[src]
impl Display for UpdateAliasErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for UpdateAliasError[src]
impl Error for UpdateAliasErrorAuto Trait Implementations
impl Send for UpdateAliasError
impl Send for UpdateAliasErrorimpl Sync for UpdateAliasError
impl Sync for UpdateAliasError