[−][src]Struct rusoto_lambda::AddPermissionRequest
Fields
action: StringThe action that the principal can use on the function. For example, lambda:InvokeFunction or lambda:GetFunction.
event_source_token: Option<String>For Alexa Smart Home functions, a token that must be supplied by the invoker.
function_name: StringThe name of the Lambda function, version, or alias.
Name formats
-
Function name -
my-function(name-only),my-function:v1(with alias). -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
principal: StringThe AWS service or account that invokes the function. If you specify a service, use SourceArn or SourceAccount to limit who can invoke the function through that service.
qualifier: Option<String>Specify a version or alias to add permissions to a published version of the function.
revision_id: Option<String>Only update the policy if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it.
source_account: Option<String>For Amazon S3, the ID of the account that owns the resource. Use this together with SourceArn to ensure that the resource is owned by the specified account. It is possible for an Amazon S3 bucket to be deleted by its owner and recreated by another account.
source_arn: Option<String>For AWS services, the ARN of the AWS resource that invokes the function. For example, an Amazon S3 bucket or Amazon SNS topic.
statement_id: StringA statement identifier that differentiates the statement from others in the same policy.