Struct rusoto_lambda::CreateAliasRequest [−][src]
pub struct CreateAliasRequest {
pub description: Option<String>,
pub function_name: String,
pub function_version: String,
pub name: String,
pub routing_config: Option<AliasRoutingConfiguration>,
}Fields
description: Option<String>
Description of the alias.
function_name: String
Name of the Lambda function for which you want to create an alias. Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 characters in length.
function_version: String
Lambda function version for which you are creating the alias.
name: String
Name for the alias you are creating.
routing_config: Option<AliasRoutingConfiguration>
Specifies an additional version your alias can point to, allowing you to dictate what percentage of traffic will invoke each version. For more information, see lambda-traffic-shifting-using-aliases.