Struct rusoto_lambda::EnvironmentError
[−]
[src]
pub struct EnvironmentError {
pub error_code: Option<String>,
pub message: Option<String>,
}The parent object that contains error information associated with your configuration settings.
Fields
error_code: Option<String>
The error code returned by the environment error object.
message: Option<String>
The message returned by the environment error object.