[−][src]Struct rusoto_lambda::EventSourceMappingConfiguration
Describes mapping between an Amazon Kinesis or DynamoDB stream or an Amazon SQS queue and a Lambda function.
Fields
batch_size: Option<i64>
The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records.
event_source_arn: Option<String>
The Amazon Resource Name (ARN) of the Amazon Kinesis or DynamoDB stream or the SQS queue that is the source of events.
function_arn: Option<String>
The Lambda function to invoke when AWS Lambda detects an event on the poll-based source.
last_modified: Option<f64>
The UTC time string indicating the last time the event mapping was updated.
last_processing_result: Option<String>
The result of the last AWS Lambda invocation of your Lambda function.
state: Option<String>
The state of the event source mapping. It can be Creating, Enabled, Disabled, Enabling, Disabling, Updating, or Deleting.
state_transition_reason: Option<String>
The reason the event source mapping is in its current state. It is either user-requested or an AWS Lambda-initiated state transition.
uuid: Option<String>
The AWS Lambda assigned opaque identifier for the mapping.