[−][src]Struct rusoto_lambda::InvocationResponse
Upon success, returns an empty response. Otherwise, throws an exception.
Fields
executed_version: Option<String>
The function version that has been executed. This value is returned only if the invocation type is RequestResponse. For more information, see lambda-traffic-shifting-using-aliases.
function_error: Option<String>
Indicates whether an error occurred while executing the Lambda function. If an error occurred this field will have one of two values; Handled or Unhandled. Handled errors are errors that are reported by the function while the Unhandled errors are those detected and reported by AWS Lambda. Unhandled errors include out of memory errors and function timeouts. For information about how to report an Handled error, see Programming Model.
log_result: Option<String>
It is the base64-encoded logs for the Lambda function invocation. This is present only if the invocation type is RequestResponse and the logs were requested.
payload: Option<Vec<u8>>
It is the JSON representation of the object returned by the Lambda function. This is present only if the invocation type is RequestResponse.
In the event of a function error this field contains a message describing the error. For the Handled errors the Lambda function will report this message. For Unhandled errors AWS Lambda reports the message.
status_code: Option<i64>
The HTTP status code will be in the 200 range for successful request. For the RequestResponse invocation type this status code will be 200. For the Event invocation type this status code will be 202. For the DryRun invocation type the status code will be 204.